@@ -11,14 +11,14 @@
 #ifndef KORG_CALENDARVIEW_H
 #define KORG_CALENDARVIEW_H
 
-#include "korganizerprivate_export.h"
 #include "helper/searchcollectionhelper.h"
+#include "korganizerprivate_export.h"
 
 #include "interfaces/korganizer/calendarviewbase.h"
 
 #include <KCalendarCore/Incidence>
-#include <KCalendarCore/Visitor>
 #include <KCalendarCore/ScheduleMessage>
+#include <KCalendarCore/Visitor>
 
 #include <Akonadi/Calendar/ITIPHandler>
 
@@ -31,19 +31,21 @@ class KODialogManager;
 class KOTodoView;
 class KOViewManager;
 class NavigatorBar;
-class KOCheckableProxyModel;
 class AkonadiCollectionView;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class CalPrinter;
 class IncidenceViewer;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class IncidenceDialog;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class History;
 class IncidenceChanger;
 class CalendarClipboard;
@@ -59,7 +61,8 @@ class CalendarViewExtension : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CalendarViewExtension(QWidget *parent) : QWidget(parent)
+    explicit CalendarViewExtension(QWidget *parent)
+        : QWidget(parent)
     {
     }
 
@@ -117,7 +120,6 @@ public:
     void showMessage(const QString &message, KMessageWidget::MessageType);
 
     Akonadi::History *history() const;
-    void setCheckableProxyModel(KOCheckableProxyModel *);
 
     KOViewManager *viewManager() const
     {
@@ -150,7 +152,7 @@ public:
     }
 
     // TODO_NG
-    //IncidenceEditors::IncidenceEditor *editorDialog( const Akonadi::Item &item ) const;
+    // IncidenceEditors::IncidenceEditor *editorDialog( const Akonadi::Item &item ) const;
     Akonadi::IncidenceChanger *incidenceChanger() const override
     {
         return mChanger;
@@ -207,9 +209,6 @@ Q_SIGNALS:
      *  for notification to update their settings. */
     void configChanged();
 
-    /** Emitted right before we die */
-    void closed(QWidget *);
-
     /** Emitted when state of modified flag changes */
     void modifiedChanged(bool);
 
@@ -290,7 +289,12 @@ public Q_SLOTS:
       Create new Event from given summary, description, attachment list and
       attendees list
     */
-    void newEvent(const QString &summary, const QString &description = QString(), const QStringList &attachment = QStringList(), const QStringList &attendees = QStringList(), const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
+    void newEvent(const QString &summary,
+                  const QString &description = QString(),
+                  const QStringList &attachment = QStringList(),
+                  const QStringList &attendees = QStringList(),
+                  const QStringList &attachmentMimetypes = QStringList(),
+                  bool inlineAttachment = false);
     void newFloatingEvent();
 
     /** Create a read-only viewer dialog for the supplied incidence.
@@ -377,7 +381,12 @@ public Q_SLOTS:
     /** create new todo with parent todo */
     void newSubTodo(const Akonadi::Collection &collection);
 
-    void newTodo(const QString &summary, const QString &description = QString(), const QStringList &attachments = QStringList(), const QStringList &attendees = QStringList(), const QStringList &attachmentMimetypes = QStringList(), bool inlineAttachment = false);
+    void newTodo(const QString &summary,
+                 const QString &description = QString(),
+                 const QStringList &attachments = QStringList(),
+                 const QStringList &attendees = QStringList(),
+                 const QStringList &attachmentMimetypes = QStringList(),
+                 bool inlineAttachment = false);
 
     void newJournal();
     void newJournal(const QDate &date);
@@ -417,14 +426,16 @@ public Q_SLOTS:
 
     /** passes on the message that an event has changed to the currently
      * activated view so that it can make appropriate display changes. */
-    void changeIncidenceDisplay(const Akonadi::Item &incidence,
-                                Akonadi::IncidenceChanger::ChangeType);
+    void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType);
 
     void slotCreateFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
     void slotModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
-    void slotDeleteFinished(int changeId, const QVector<Akonadi::Item::Id> &itemIdList, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
+    void slotDeleteFinished(int changeId,
+                            const QVector<Akonadi::Item::Id> &itemIdList,
+                            Akonadi::IncidenceChanger::ResultCode resultCode,
+                            const QString &errorString);
 
     void startMultiModify(const QString &text);
     void endMultiModify();
@@ -571,7 +582,7 @@ public Q_SLOTS:
      * @param preferredMonth Holds the month that should be selected when
      * the week crosses months.  It's a QDate instead of uint so it can be
      * easily fed to KCalendarSystem's functions.
-    */
+     */
     void selectWeek(const QDate &week, const QDate &preferredMonth);
 
     /**
@@ -591,8 +602,6 @@ protected Q_SLOTS:
     void showDates(const KCalendarCore::DateList &, const QDate &preferredMonth = QDate());
 
 public:
-    int msgCalModified();
-
     /**
      * Returns the date of the selected incidence.
      *
@@ -650,15 +659,13 @@ private:
      * If mimeType is set, the collection to return will have to support that mime type.
      * If no valid collection is found, an invalid one is returned.
      */
-    Akonadi::Collection defaultCollection(
-        const QLatin1String &mimeType = QLatin1String("")) const;
+    Akonadi::Collection defaultCollection(const QLatin1String &mimeType = QLatin1String("")) const;
 
     /**
      * Creates a new incidence editor and chooses a decent default for the collection
      * in the collection combo.
      */
-    IncidenceEditorNG::IncidenceDialog *createIncidenceEditor(
-        const Akonadi::Item &item, const Akonadi::Collection &collection = Akonadi::Collection());
+    IncidenceEditorNG::IncidenceDialog *createIncidenceEditor(const Akonadi::Item &item, const Akonadi::Collection &collection = Akonadi::Collection());
 
     CalendarSupport::CalPrinter *mCalPrinter = nullptr;
     Akonadi::TodoPurger *mTodoPurger = nullptr;
@@ -692,7 +699,7 @@ private:
     KCalendarCore::CalFilter *mCurrentFilter = nullptr;
 
     // various housekeeping variables.
-    bool mReadOnly;  // flag indicating if calendar is read-only
+    bool mReadOnly; // flag indicating if calendar is read-only
 
     Akonadi::Item mSelectedIncidence;
     QDate mSaveDate;
@@ -704,7 +711,6 @@ private:
     bool mSplitterSizesValid;
 
     Akonadi::CalendarClipboard *mCalendarClipboard = nullptr;
-    KOCheckableProxyModel *mCheckableProxyModel = nullptr;
     AkonadiCollectionView *mETMCollectionView = nullptr;
 
     SearchCollectionHelper mSearchCollectionHelper;
