@@ -15,10 +15,12 @@ class QLineEdit;
 class KIconButton;
 class QCheckBox;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class IncidencesForWidget;
 }
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class KORGANIZERPRIVATE_EXPORT CollectionGeneralPage : public Akonadi::CollectionPropertiesPage
 {
     Q_OBJECT
