@@ -14,11 +14,13 @@
 #include <QDialog>
 class QPushButton;
 
-namespace CalendarSupport {
+namespace CalendarSupport
+{
 class IncidenceViewer;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Item;
 class ETMCalendar;
 }
