@@ -15,8 +15,8 @@
 
 #include <KCalendarCore/IncidenceBase> //for KCalendarCore::DateList typedef
 
-#include <QFrame>
 #include <QDate>
+#include <QFrame>
 
 /**
  *  Replacement for kdpdatebuton.cpp that used 42 widgets for the day
@@ -64,7 +64,7 @@ public:
 
     /** destructor that deallocates all dynamically allocated private members.
      */
-    ~KODayMatrix();
+    ~KODayMatrix() override;
 
     /** returns the first and last date of the 6*7 matrix that displays @p month
      * @param month The month we want to get matrix boundaries
