@@ -15,7 +15,8 @@
 
 #include <KCalendarCore/Incidence>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class Collection;
 class Item;
 }
@@ -25,7 +26,8 @@ class QDate;
 
 // Provides static methods that are useful to all views.
 
-namespace KOHelper {
+namespace KOHelper
+{
 /**
   Returns a nice QColor for text, give the input color &c.
 */
@@ -52,12 +54,11 @@ KORGANIZERPRIVATE_EXPORT void setResourceColor(const Akonadi::Collection &collec
 KORGANIZERPRIVATE_EXPORT Q_REQUIRED_RESULT int yearDiff(QDate start, QDate end);
 
 /**
-  Return true if it's the standard calendar
+  Return true if it's the standard (that is, the current default) calendar.
 */
 KORGANIZERPRIVATE_EXPORT Q_REQUIRED_RESULT bool isStandardCalendar(Akonadi::Collection::Id id);
 
-KORGANIZERPRIVATE_EXPORT void showSaveIncidenceErrorMsg(
-    QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence);
+KORGANIZERPRIVATE_EXPORT void showSaveIncidenceErrorMsg(QWidget *parent, const KCalendarCore::Incidence::Ptr &incidence);
 }
 
 #endif
