@@ -15,7 +15,8 @@ class MyDesignerFields : public KCMDesignerFields
 {
     Q_OBJECT
 public:
-    MyDesignerFields() : KCMDesignerFields(nullptr)
+    MyDesignerFields()
+        : KCMDesignerFields(nullptr)
     {
     }
 
@@ -54,7 +55,7 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    auto *kcm = new MyDesignerFields();
+    auto kcm = new MyDesignerFields();
     kcm->show();
 
     app.exec();
